# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2020-03-30 14:42
from __future__ import unicode_literals

from django.db import migrations, models
import djangoldp.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Dashboard',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('size', models.CharField(choices=[('1', '1'), ('2', '2'), ('3', '3')], default='1', max_length=1)),
                ('content', models.CharField(max_length=255)),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
    ]



from django.db import models
from djangoldp.models import Model

SIZE_CHOICES = [
    ('1', '1'),
    ('2', '2'),
    ('3', '3')
]

class Dashboard(Model):
    size = models.CharField(max_length=1, choices=SIZE_CHOICES, default='1')
    content = models.TextField()



# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2020-03-30 15:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_dashboard', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dashboard',
            name='content',
            field=models.TextField(),
        ),
    ]
